==> civicrm_4.7.30+dfsg.orig.tar.xz: civicrm/CRM/Core/Smarty/plugins/modifier.crmAddClass.php <==
<?php
/*
 +--------------------------------------------------------------------+
 | CiviCRM version 4.7                                                |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2017                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
 */

/**
 *
 * @package CRM
 * @copyright CiviCRM LLC (c) 2004-2017
 * $Id$
 *
 */

/**
 * Add a class to an html element
 *
 * @param string $string
 *   The html to be tweaked.
 * @param string $class
 *   The new class or classes to add (separate with a space).
 *
 * @return string
 *   the new modified html string
 */
function smarty_modifier_crmAddClass($string, $class) {
  // Standardize white space
  $string = str_replace(array('class ="', 'class= "', 'class = "'), 'class="', $string);
  if (strpos($string, 'class="') !== FALSE) {
    $string = str_replace('class="', 'class="' . "$class ", $string);
  }
  else {
    $string = str_replace('>', ' class="' . $class . '">', $string);
  }
  return $string;
}

==> civicrm_5.8.0+dfsg.orig.tar.xz: civicrm/CRM/Core/Smarty/plugins/modifier.crmAddClass.php <==
<?php
/*
 +--------------------------------------------------------------------+
 | CiviCRM version 5                                                  |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2018                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
 */

/**
 *
 * @package CRM
 * @copyright CiviCRM LLC (c) 2004-2018
 * $Id$
 *
 */

/**
 * Add a class to an html element
 *
 * @param string $string
 *   The html to be tweaked.
 * @param string $class
 *   The new class or classes to add (separate with a space).
 *
 * @return string
 *   the new modified html string
 */
function smarty_modifier_crmAddClass($string, $class) {
  // Standardize white space
  $string = str_replace(array('class ="', 'class= "', 'class = "'), 'class="', $string);
  if (strpos($string, 'class="') !== FALSE) {
    $string = str_replace('class="', 'class="' . "$class ", $string);
  }
  else {
    $string = str_replace('>', ' class="' . $class . '">', $string);
  }
  return $string;
}
